using System;
using System.Data;
using System.Configuration;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
// Import XML namespace.
using System.Xml;

public partial class _ReadXml : System.Web.UI.Page 
{
    protected void Page_Load(object sender, System.EventArgs e)
    {
        // Code is executed only if the page load not is a post back
        if (!Page.IsPostBack)
        {
            // When the page loads we get the user id from a session variable and saves this in a hidden field

            HiddenUserID.Value = Convert.ToString(Session["UserID"]);

        }

        // Code is executed only if the page load not is a post back
        if (Page.IsPostBack == false)
        {

            if ((Context.Items["url"] != null))
            {
                // We get the url of the xml-file that we want to get data from. The url is sent to this page
                // with a Server.Transfer that have used Context.Items.Add("url") to send the value. We get
                // the value for the url by Context.Items("url")

                string XmlUrl = Convert.ToString(Context.Items["url"]);

                // We create a new XmlDocument to get data from a Xml-file and loads the file according to the path in "XmlUrl"
                XmlDocument textReader = new XmlDocument();
                textReader.Load(Server.MapPath(XmlUrl));

                //Create an XmlNamespaceManager for resolving namespaces.
                XmlNamespaceManager xbrli = new XmlNamespaceManager(textReader.NameTable);
                XmlNamespaceManager secdbase = new XmlNamespaceManager(textReader.NameTable);
                XmlNamespaceManager genbase = new XmlNamespaceManager(textReader.NameTable);
                xbrli.AddNamespace("xbrli", "http://www.xbrl.org/2003/instance");
                secdbase.AddNamespace("se-cd-base", "http://www.xbrl.se/se/fr/cd-base/2007-05-25");
                genbase.AddNamespace("se-gen-base", "http://www.xbrl.se/se/fr/gen-base/2007-05-25");

                // The root node for the document
                XmlNode root = textReader.DocumentElement;

                // General company and reporting information
                txtFirma.Text = root.SelectSingleNode("se-cd-base:Firma", secdbase).ChildNodes[0].Value;
                txtOrganisationsnummer.Text = root.SelectSingleNode("se-cd-base:Organisationsnummer", secdbase).ChildNodes[0].Value;
                txtBeloppsformat.SelectedValue = root.SelectSingleNode("se-cd-base:Beloppsformat", secdbase).ChildNodes[0].Value;
                if (txtBeloppsformat.SelectedValue == "NORMALFORM")
                {
                    txtDecimals.Text = "INF";
                }
                else
                {
                    txtDecimals.Text = "-3";
                }
                txtRedovisningsvaluta.SelectedValue = root.SelectSingleNode("se-cd-base:Redovisningsvaluta", secdbase).ChildNodes[0].Value;

                // Reporting year, innevarande rakenskapsar, current year
                txtRakenskapsarStartDatePeriod0.Text = root.SelectSingleNode("//xbrli:context[@id='PERIOD0']//xbrli:startDate", xbrli).ChildNodes[0].Value;
                txtRakenskapsarEndDatePeriod0.Text = root.SelectSingleNode("//xbrli:context[@id='PERIOD0']//xbrli:endDate", xbrli).ChildNodes[0].Value;

                // Comparing year, jamforelsear, previous year
                XmlNode StartPeriodM1 = root.SelectSingleNode("//xbrli:context[@id='PERIOD-1']//xbrli:startDate", xbrli);
                if ((StartPeriodM1 != null))
                {
                    txtRakenskapsarStartDatePeriodm1.Text = StartPeriodM1.ChildNodes[0].Value;
                    StartPeriodM1 = null;
                }
                XmlNode EndPeriodM1 = root.SelectSingleNode("//xbrli:context[@id='PERIOD-1']//xbrli:endDate", xbrli);
                if ((EndPeriodM1 != null))
                {
                    txtRakenskapsarEndDatePeriodm1.Text = EndPeriodM1.ChildNodes[0].Value;
                    EndPeriodM1 = null;
                }

                // /////////////////////// Forvaltningsberattelsen ///////////////////
                XmlNode BusinessDescription = root.SelectSingleNode("se-gen-base:Verksamheten", genbase);
                if ((BusinessDescription != null))
                {
                    txtVerksamheten.Text = BusinessDescription.ChildNodes[0].Value;
                    BusinessDescription = null;
                }
                XmlNode ImportantEvents = root.SelectSingleNode("se-gen-base:VasentligaHandelserUnderOchEfterRakenskapsaretsSlut", genbase);
                if ((ImportantEvents != null))
                {
                    txtVasantligaHandelser.Text = ImportantEvents.ChildNodes[0].Value;
                    ImportantEvents = null;
                }
                XmlNode FutureDevelopment = root.SelectSingleNode("se-gen-base:FramtidaUtveckling", genbase);
                if ((FutureDevelopment != null))
                {
                    txtFramtidaUtveckling.Text = FutureDevelopment.ChildNodes[0].Value;
                    FutureDevelopment = null;
                }
                XmlNode EnvironmentPollution = root.SelectSingleNode("se-gen-base:Miljopaverkan", genbase);
                if ((EnvironmentPollution != null))
                {
                    txtMiljoPaverkan.Text = EnvironmentPollution.ChildNodes[0].Value;
                    EnvironmentPollution = null;
                }

                //Medel att disponera
                XmlNode MedelAttDisponeraOverkursfondObj = root.SelectSingleNode("se-gen-base:MedelAttDisponeraOverkursfond", genbase);
                if ((MedelAttDisponeraOverkursfondObj != null))
                {
                    MedelAttDisponeraOverkursfond.Text = MedelAttDisponeraOverkursfondObj.ChildNodes[0].Value;
                    MedelAttDisponeraOverkursfondObj = null;
                }
                XmlNode MedelAttDisponeraFondForVerkligtVardeObj = root.SelectSingleNode("se-gen-base:MedelAttDisponeraFondForVerkligtVarde", genbase);
                if ((MedelAttDisponeraFondForVerkligtVardeObj != null))
                {
                    MedelAttDisponeraFondForVerkligtVarde.Text = MedelAttDisponeraFondForVerkligtVardeObj.ChildNodes[0].Value;
                    MedelAttDisponeraFondForVerkligtVardeObj = null;
                }
                XmlNode MedelAttDisponeraBalanseratResultatObj = root.SelectSingleNode("se-gen-base:MedelAttDisponeraBalanseratResultat", genbase);
                if ((MedelAttDisponeraBalanseratResultatObj != null))
                {
                    MedelAttDisponeraBalanseratResultat.Text = MedelAttDisponeraBalanseratResultatObj.ChildNodes[0].Value;
                    MedelAttDisponeraBalanseratResultatObj = null;
                }
                XmlNode MedelAttDisponeraKoncernbidragObj = root.SelectSingleNode("se-gen-base:MedelAttDisponeraKoncernbidrag", genbase);
                if ((MedelAttDisponeraKoncernbidragObj != null))
                {
                    MedelAttDisponeraKoncernbidrag.Text = MedelAttDisponeraKoncernbidragObj.ChildNodes[0].Value;
                    MedelAttDisponeraKoncernbidragObj = null;
                }
                XmlNode MedelAttDisponeraErhallnaAktieagartillskottObj = root.SelectSingleNode("se-gen-base:MedelAttDisponeraErhallnaAktieagartillskott", genbase);
                if ((MedelAttDisponeraErhallnaAktieagartillskottObj != null))
                {
                    MedelAttDisponeraErhallnaAktieagartillskott.Text = MedelAttDisponeraErhallnaAktieagartillskottObj.ChildNodes[0].Value;
                    MedelAttDisponeraErhallnaAktieagartillskottObj = null;
                }
                XmlNode MedelAttDisponeraAretsResultatObj = root.SelectSingleNode("se-gen-base:MedelAttDisponeraAretsResultat", genbase);
                if ((MedelAttDisponeraAretsResultatObj != null))
                {
                    MedelAttDisponeraAretsResultat.Text = MedelAttDisponeraAretsResultatObj.ChildNodes[0].Value;
                    MedelAttDisponeraAretsResultatObj = null;
                }
                XmlNode MedelAttDisponeraObj = root.SelectSingleNode("se-gen-base:MedelAttDisponera", genbase);
                if ((MedelAttDisponeraObj != null))
                {
                    MedelAttDisponeraSumma.Text = MedelAttDisponeraObj.ChildNodes[0].Value;
                    MedelAttDisponeraObj = null;
                }

                // Forslag till disposition
                XmlNode ForslagDispositionUtdelningObj = root.SelectSingleNode("se-gen-base:ForslagDispositionUtdelning", genbase);
                if ((ForslagDispositionUtdelningObj != null))
                {
                    ForslagDispositionUtdelning.Text = ForslagDispositionUtdelningObj.ChildNodes[0].Value;
                    ForslagDispositionUtdelningObj = null;
                }
                XmlNode ForslagDispositionFondemissionObj = root.SelectSingleNode("se-gen-base:ForslagDispositionFondemission", genbase);
                if ((ForslagDispositionFondemissionObj != null))
                {
                    ForslagDispositionFondemission.Text = ForslagDispositionFondemissionObj.ChildNodes[0].Value;
                    ForslagDispositionFondemissionObj = null;
                }
                XmlNode ForslagDispositionAvsattningTillReservfondObj = root.SelectSingleNode("se-gen-base:ForslagDispositionAvsattningReservfond", genbase);
                if ((ForslagDispositionAvsattningTillReservfondObj != null))
                {
                    ForslagDispositionAvsattningTillReservfond.Text = ForslagDispositionAvsattningTillReservfondObj.ChildNodes[0].Value;
                    ForslagDispositionAvsattningTillReservfondObj = null;
                }
                XmlNode ForslagDispositionIanspraktagandeAvReservFondObj = root.SelectSingleNode("se-gen-base:ForslagDispositionIanspraktagandeAvReservfond", genbase);
                if ((ForslagDispositionIanspraktagandeAvReservFondObj != null))
                {
                    ForslagDispositionIanspraktagandeAvReservFond.Text = ForslagDispositionIanspraktagandeAvReservFondObj.ChildNodes[0].Value;
                    ForslagDispositionIanspraktagandeAvReservFondObj = null;
                }
                XmlNode ForslagDispositionIanspraktagandeAvUppskrivningsfondObj = root.SelectSingleNode("se-gen-base:ForslagDispositionIanspraktagandeAvUppskrivningsfond", genbase);
                if ((ForslagDispositionIanspraktagandeAvUppskrivningsfondObj != null))
                {
                    ForslagDispositionIanspraktagandeAvUppskrivningsfond.Text = ForslagDispositionIanspraktagandeAvUppskrivningsfondObj.ChildNodes[0].Value;
                    ForslagDispositionIanspraktagandeAvUppskrivningsfondObj = null;
                }
                XmlNode ForslagDispositionBalanserasINyRakningObj = root.SelectSingleNode("se-gen-base:ForslagDispositionBalanserasINyRakning", genbase);
                if ((ForslagDispositionBalanserasINyRakningObj != null))
                {
                    ForslagDispositionBalanserasINyRakning.Text = ForslagDispositionBalanserasINyRakningObj.ChildNodes[0].Value;
                    ForslagDispositionBalanserasINyRakningObj = null;
                }
                XmlNode ForslagDispositionSummaObj = root.SelectSingleNode("se-gen-base:ForslagDispositionSumma", genbase);
                if ((ForslagDispositionSummaObj != null))
                {
                    ForslagDispositionSumma.Text = ForslagDispositionSummaObj.ChildNodes[0].Value;
                    ForslagDispositionSummaObj = null;
                }

                XmlNode txtKommentarDispositionerObj = root.SelectSingleNode("se-gen-base:DispositionerVinstEllerForlustKommentar", genbase);
                if ((txtKommentarDispositionerObj != null))
                {
                    txtKommentarDispositioner.Text = txtKommentarDispositionerObj.ChildNodes[0].Value;
                    txtKommentarDispositionerObj = null;
                }
                XmlNode StyrelsensYttrandeVinstutdelningObj = root.SelectSingleNode("se-gen-base:StyrelsensYttrandeVinstutdelning", genbase);
                if ((StyrelsensYttrandeVinstutdelningObj != null))
                {
                    StyrelsensYttrandeVinstutdelning.Text = StyrelsensYttrandeVinstutdelningObj.ChildNodes[0].Value;
                    StyrelsensYttrandeVinstutdelningObj = null;
                }
                XmlNode ResultatOchStallningObj = root.SelectSingleNode("se-gen-base:ResultatOchStallning", genbase);
                if ((ResultatOchStallningObj != null))
                {
                    ResultatOchStallning.Text = ResultatOchStallningObj.ChildNodes[0].Value;
                    ResultatOchStallningObj = null;
                }

                // ////////////////// Resultatrkning ////////////////////
                // Rorelsens intakter
                XmlNode NettoomsattningRES0Obj = root.SelectSingleNode("se-gen-base:Nettoomsattning[@contextRef='PERIOD0']", genbase);
                if ((NettoomsattningRES0Obj != null))
                {
                    NettoomsattningRES0.Text = NettoomsattningRES0Obj.ChildNodes[0].Value;
                    NettoomsattningRES0Obj = null;
                }
                XmlNode NettoomsattningRESm1Obj = root.SelectSingleNode("se-gen-base:Nettoomsattning[@contextRef='PERIOD-1']", genbase);
                if ((NettoomsattningRESm1Obj != null))
                {
                    NettoomsattningRESm1.Text = NettoomsattningRESm1Obj.ChildNodes[0].Value;
                    NettoomsattningRESm1Obj = null;
                }
                XmlNode KostnadSaldaVarorRES0Obj = root.SelectSingleNode("se-gen-base:KostnadSaldaVaror[@contextRef='PERIOD0']", genbase);
                if ((KostnadSaldaVarorRES0Obj != null))
                {
                    KostnadSaldaVarorRES0.Text = KostnadSaldaVarorRES0Obj.ChildNodes[0].Value;
                    KostnadSaldaVarorRES0Obj = null;
                }
                XmlNode KostnadSaldaVarorRESm1Obj = root.SelectSingleNode("se-gen-base:KostnadSaldaVaror[@contextRef='PERIOD-1']", genbase);
                if ((KostnadSaldaVarorRESm1Obj != null))
                {
                    KostnadSaldaVarorRESm1.Text = KostnadSaldaVarorRESm1Obj.ChildNodes[0].Value;
                    KostnadSaldaVarorRESm1Obj = null;
                }
                XmlNode BruttoresultatRES0Obj = root.SelectSingleNode("se-gen-base:Bruttoresultat[@contextRef='PERIOD0']", genbase);
                if ((BruttoresultatRES0Obj != null))
                {
                    BruttoresultatRES0.Text = BruttoresultatRES0Obj.ChildNodes[0].Value;
                    BruttoresultatRES0Obj = null;
                }
                XmlNode BruttoresultatRESm1Obj = root.SelectSingleNode("se-gen-base:Bruttoresultat[@contextRef='PERIOD-1']", genbase);
                if ((BruttoresultatRESm1Obj != null))
                {
                    BruttoresultatRESm1.Text = BruttoresultatRESm1Obj.ChildNodes[0].Value;
                    BruttoresultatRESm1Obj = null;
                }
                XmlNode ForsaljningskostnaderRES0Obj = root.SelectSingleNode("se-gen-base:Forsaljningskostnader[@contextRef='PERIOD0']", genbase);
                if ((ForsaljningskostnaderRES0Obj != null))
                {
                    ForsaljningskostnaderRES0.Text = ForsaljningskostnaderRES0Obj.ChildNodes[0].Value;
                    ForsaljningskostnaderRES0Obj = null;
                }
                XmlNode ForsaljningskostnaderRESm1Obj = root.SelectSingleNode("se-gen-base:Forsaljningskostnader[@contextRef='PERIOD-1']", genbase);
                if ((ForsaljningskostnaderRESm1Obj != null))
                {
                    ForsaljningskostnaderRESm1.Text = ForsaljningskostnaderRESm1Obj.ChildNodes[0].Value;
                    ForsaljningskostnaderRESm1Obj = null;
                }
                XmlNode AdministrationskostnaderRES0Obj = root.SelectSingleNode("se-gen-base:Administrationskostnader[@contextRef='PERIOD0']", genbase);
                if ((AdministrationskostnaderRES0Obj != null))
                {
                    AdministrationskostnaderRES0.Text = AdministrationskostnaderRES0Obj.ChildNodes[0].Value;
                    AdministrationskostnaderRES0Obj = null;
                }
                XmlNode AdministrationskostnaderRESm1Obj = root.SelectSingleNode("se-gen-base:Administrationskostnader[@contextRef='PERIOD-1']", genbase);
                if ((AdministrationskostnaderRESm1Obj != null))
                {
                    AdministrationskostnaderRESm1.Text = AdministrationskostnaderRESm1Obj.ChildNodes[0].Value;
                    AdministrationskostnaderRESm1Obj = null;
                }
                XmlNode ForskningUtvecklingRES0Obj = root.SelectSingleNode("se-gen-base:ForskningsUtvecklingskostnader[@contextRef='PERIOD0']", genbase);
                if ((ForskningUtvecklingRES0Obj != null))
                {
                    ForskningUtvecklingRES0.Text = ForskningUtvecklingRES0Obj.ChildNodes[0].Value;
                    ForskningUtvecklingRES0Obj = null;
                }
                XmlNode ForskningUtvecklingRESm1Obj = root.SelectSingleNode("se-gen-base:ForskningsUtvecklingskostnader[@contextRef='PERIOD-1']", genbase);
                if ((ForskningUtvecklingRESm1Obj != null))
                {
                    ForskningUtvecklingRESm1.Text = ForskningUtvecklingRESm1Obj.ChildNodes[0].Value;
                    ForskningUtvecklingRESm1Obj = null;
                }
                XmlNode LagerforandringRES0Obj = root.SelectSingleNode("se-gen-base:ForandringAvLagerAvProdukterIArbeteFardigaVarorOchPagaendeArbetenForAnnansRakning[@contextRef='PERIOD0']", genbase);
                if ((LagerforandringRES0Obj != null))
                {
                    LagerforandringRES0.Text = LagerforandringRES0Obj.ChildNodes[0].Value;
                    LagerforandringRES0Obj = null;
                }
                XmlNode LagerforandringRESm1Obj = root.SelectSingleNode("se-gen-base:ForandringAvLagerAvProdukterIArbeteFardigaVarorOchPagaendeArbetenForAnnansRakning[@contextRef='PERIOD-1']", genbase);
                if ((LagerforandringRESm1Obj != null))
                {
                    LagerforandringRESm1.Text = LagerforandringRESm1Obj.ChildNodes[0].Value;
                    LagerforandringRESm1Obj = null;
                }
                XmlNode AktiveratArbeteForEgenRakningRES0Obj = root.SelectSingleNode("se-gen-base:AktiveratArbeteForEgenRakning[@contextRef='PERIOD0']", genbase);
                if ((AktiveratArbeteForEgenRakningRES0Obj != null))
                {
                    AktiveratArbeteForEgenRakningRES0.Text = AktiveratArbeteForEgenRakningRES0Obj.ChildNodes[0].Value;
                    AktiveratArbeteForEgenRakningRES0Obj = null;
                }
                XmlNode AktiveratArbeteForEgenRakningRESm1Obj = root.SelectSingleNode("se-gen-base:AktiveratArbeteForEgenRakning[@contextRef='PERIOD-1']", genbase);
                if ((AktiveratArbeteForEgenRakningRESm1Obj != null))
                {
                    AktiveratArbeteForEgenRakningRESm1.Text = AktiveratArbeteForEgenRakningRESm1Obj.ChildNodes[0].Value;
                    AktiveratArbeteForEgenRakningRESm1Obj = null;
                }
                XmlNode OvrigaRorelseIntakterRES0Obj = root.SelectSingleNode("se-gen-base:OvrigaRorelseintakter[@contextRef='PERIOD0']", genbase);
                if ((OvrigaRorelseIntakterRES0Obj != null))
                {
                    OvrigaRorelseIntakterRES0.Text = OvrigaRorelseIntakterRES0Obj.ChildNodes[0].Value;
                    OvrigaRorelseIntakterRES0Obj = null;
                }
                XmlNode OvrigaRorelseIntakterRESm1Obj = root.SelectSingleNode("se-gen-base:OvrigaRorelseintakter[@contextRef='PERIOD-1']", genbase);
                if ((OvrigaRorelseIntakterRESm1Obj != null))
                {
                    OvrigaRorelseIntakterRESm1.Text = OvrigaRorelseIntakterRESm1Obj.ChildNodes[0].Value;
                    OvrigaRorelseIntakterRESm1Obj = null;
                }
                XmlNode RorelseintakterLagerforandringarMmRES0Obj = root.SelectSingleNode("se-gen-base:RorelseintakterLagerforandringarMm[@contextRef='PERIOD0']", genbase);
                if ((RorelseintakterLagerforandringarMmRES0Obj != null))
                {
                    RorelseintakterLagerforandringarMmRES0.Text = RorelseintakterLagerforandringarMmRES0Obj.ChildNodes[0].Value;
                    RorelseintakterLagerforandringarMmRES0Obj = null;
                }
                XmlNode RorelseintakterLagerforandringarMmRESm1Obj = root.SelectSingleNode("se-gen-base:RorelseintakterLagerforandringarMm[@contextRef='PERIOD-1']", genbase);
                if ((RorelseintakterLagerforandringarMmRESm1Obj != null))
                {
                    RorelseintakterLagerforandringarMmRESm1.Text = RorelseintakterLagerforandringarMmRESm1Obj.ChildNodes[0].Value;
                    RorelseintakterLagerforandringarMmRESm1Obj = null;
                }

                // Rorelsens kostnader
                XmlNode RavarorOchFornodenheterResultatrakningenRES0Obj = root.SelectSingleNode("se-gen-base:RavarorFornodenheterResultatrakningen[@contextRef='PERIOD0']", genbase);
                if ((RavarorOchFornodenheterResultatrakningenRES0Obj != null))
                {
                    RavarorOchFornodenheterResultatrakningenRES0.Text = RavarorOchFornodenheterResultatrakningenRES0Obj.ChildNodes[0].Value;
                    RavarorOchFornodenheterResultatrakningenRES0Obj = null;
                }
                XmlNode RavarorOchFornodenheterResultatrakningenRESm1Obj = root.SelectSingleNode("se-gen-base:RavarorFornodenheterResultatrakningen[@contextRef='PERIOD-1']", genbase);
                if ((RavarorOchFornodenheterResultatrakningenRESm1Obj != null))
                {
                    RavarorOchFornodenheterResultatrakningenRESm1.Text = RavarorOchFornodenheterResultatrakningenRESm1Obj.ChildNodes[0].Value;
                    RavarorOchFornodenheterResultatrakningenRESm1Obj = null;
                }
                XmlNode HandelsvarorRES0Obj = root.SelectSingleNode("se-gen-base:Handelsvaror[@contextRef='PERIOD0']", genbase);
                if ((HandelsvarorRES0Obj != null))
                {
                    HandelsvarorRES0.Text = HandelsvarorRES0Obj.ChildNodes[0].Value;
                    HandelsvarorRES0Obj = null;
                }
                XmlNode HandelsvarorRESm1Obj = root.SelectSingleNode("se-gen-base:Handelsvaror[@contextRef='PERIOD-1']", genbase);
                if ((HandelsvarorRESm1Obj != null))
                {
                    HandelsvarorRESm1.Text = HandelsvarorRESm1Obj.ChildNodes[0].Value;
                    HandelsvarorRESm1Obj = null;
                }
                XmlNode OvrigaExternaKostnaderRES0Obj = root.SelectSingleNode("se-gen-base:OvrigaExternaKostnader[@contextRef='PERIOD0']", genbase);
                if ((OvrigaExternaKostnaderRES0Obj != null))
                {
                    OvrigaExternaKostnaderRES0.Text = OvrigaExternaKostnaderRES0Obj.ChildNodes[0].Value;
                    OvrigaExternaKostnaderRES0Obj = null;
                }
                XmlNode OvrigaExternaKostnaderRESm1Obj = root.SelectSingleNode("se-gen-base:OvrigaExternaKostnader[@contextRef='PERIOD-1']", genbase);
                if ((OvrigaExternaKostnaderRESm1Obj != null))
                {
                    OvrigaExternaKostnaderRESm1.Text = OvrigaExternaKostnaderRESm1Obj.ChildNodes[0].Value;
                    OvrigaExternaKostnaderRESm1Obj = null;
                }
                XmlNode PersonalkostnaderRES0Obj = root.SelectSingleNode("se-gen-base:Personalkostnader[@contextRef='PERIOD0']", genbase);
                if ((PersonalkostnaderRES0Obj != null))
                {
                    PersonalkostnaderRES0.Text = PersonalkostnaderRES0Obj.ChildNodes[0].Value;
                    PersonalkostnaderRES0Obj = null;
                }
                XmlNode PersonalkostnaderRESm1Obj = root.SelectSingleNode("se-gen-base:Personalkostnader[@contextRef='PERIOD-1']", genbase);
                if ((PersonalkostnaderRESm1Obj != null))
                {
                    PersonalkostnaderRESm1.Text = PersonalkostnaderRESm1Obj.ChildNodes[0].Value;
                    PersonalkostnaderRESm1Obj = null;
                }
                XmlNode AvskrivningarOchNedskrivningarAvMateriellaOchImmateriellaAnlaggningstillgangarRES0Obj = root.SelectSingleNode("se-gen-base:AvskrivningarOchNedskrivningarMateriellaOchImmateriellaAnlaggningstillgangar[@contextRef='PERIOD0']", genbase);
                if ((AvskrivningarOchNedskrivningarAvMateriellaOchImmateriellaAnlaggningstillgangarRES0Obj != null))
                {
                    AvskrivningarOchNedskrivningarAvMateriellaOchImmateriellaAnlaggningstillgangarRES0.Text = AvskrivningarOchNedskrivningarAvMateriellaOchImmateriellaAnlaggningstillgangarRES0Obj.ChildNodes[0].Value;
                    AvskrivningarOchNedskrivningarAvMateriellaOchImmateriellaAnlaggningstillgangarRES0Obj = null;
                }
                XmlNode AvskrivningarOchNedskrivningarAvMateriellaOchImmateriellaAnlaggningstillgangarRESm1Obj = root.SelectSingleNode("se-gen-base:AvskrivningarOchNedskrivningarMateriellaOchImmateriellaAnlaggningstillgangar[@contextRef='PERIOD-1']", genbase);
                if ((AvskrivningarOchNedskrivningarAvMateriellaOchImmateriellaAnlaggningstillgangarRESm1Obj != null))
                {
                    AvskrivningarOchNedskrivningarAvMateriellaOchImmateriellaAnlaggningstillgangarRESm1.Text = AvskrivningarOchNedskrivningarAvMateriellaOchImmateriellaAnlaggningstillgangarRESm1Obj.ChildNodes[0].Value;
                    AvskrivningarOchNedskrivningarAvMateriellaOchImmateriellaAnlaggningstillgangarRESm1Obj = null;
                }
                XmlNode NedskrivningarAvOmsattningstillgangarUtoverNormalaNedskrivningarRES0Obj = root.SelectSingleNode("se-gen-base:NedskrivningarOmsattningstillgangarUtoverNormalaNedskrivningar[@contextRef='PERIOD0']", genbase);
                if ((NedskrivningarAvOmsattningstillgangarUtoverNormalaNedskrivningarRES0Obj != null))
                {
                    NedskrivningarAvOmsattningstillgangarUtoverNormalaNedskrivningarRES0.Text = NedskrivningarAvOmsattningstillgangarUtoverNormalaNedskrivningarRES0Obj.ChildNodes[0].Value;
                    NedskrivningarAvOmsattningstillgangarUtoverNormalaNedskrivningarRES0Obj = null;
                }
                XmlNode NedskrivningarAvOmsattningstillgangarUtoverNormalaNedskrivningarRESm1Obj = root.SelectSingleNode("se-gen-base:NedskrivningarOmsattningstillgangarUtoverNormalaNedskrivningar[@contextRef='PERIOD-1']", genbase);
                if ((NedskrivningarAvOmsattningstillgangarUtoverNormalaNedskrivningarRESm1Obj != null))
                {
                    NedskrivningarAvOmsattningstillgangarUtoverNormalaNedskrivningarRESm1.Text = NedskrivningarAvOmsattningstillgangarUtoverNormalaNedskrivningarRESm1Obj.ChildNodes[0].Value;
                    NedskrivningarAvOmsattningstillgangarUtoverNormalaNedskrivningarRESm1Obj = null;
                }
                XmlNode OvrigaRorelsekostnaderRES0Obj = root.SelectSingleNode("se-gen-base:OvrigaRorelsekostnader[@contextRef='PERIOD0']", genbase);
                if ((OvrigaRorelsekostnaderRES0Obj != null))
                {
                    OvrigaRorelsekostnaderRES0.Text = OvrigaRorelsekostnaderRES0Obj.ChildNodes[0].Value;
                    OvrigaRorelsekostnaderRES0Obj = null;
                }
                XmlNode OvrigaRorelsekostnaderRESm1Obj = root.SelectSingleNode("se-gen-base:OvrigaRorelsekostnader[@contextRef='PERIOD-1']", genbase);
                if ((OvrigaRorelsekostnaderRESm1Obj != null))
                {
                    OvrigaRorelsekostnaderRESm1.Text = OvrigaRorelsekostnaderRESm1Obj.ChildNodes[0].Value;
                    OvrigaRorelsekostnaderRESm1Obj = null;
                }
                XmlNode SummaFunktionerRES0Obj = root.SelectSingleNode("se-gen-base:FunktionerMmSumma[@contextRef='PERIOD0']", genbase);
                if ((SummaFunktionerRES0Obj != null))
                {
                    SummaFunktionerRES0.Text = SummaFunktionerRES0Obj.ChildNodes[0].Value;
                    SummaFunktionerRES0Obj = null;
                }
                XmlNode SummaFunktionerRESm1Obj = root.SelectSingleNode("se-gen-base:FunktionerMmSumma[@contextRef='PERIOD-1']", genbase);
                if ((SummaFunktionerRESm1Obj != null))
                {
                    SummaFunktionerRESm1.Text = SummaFunktionerRESm1Obj.ChildNodes[0].Value;
                    SummaFunktionerRESm1Obj = null;
                }
                XmlNode RorelsekostnaderRES0Obj = root.SelectSingleNode("se-gen-base:Rorelsekostnader[@contextRef='PERIOD0']", genbase);
                if ((RorelsekostnaderRES0Obj != null))
                {
                    RorelsekostnaderRES0.Text = RorelsekostnaderRES0Obj.ChildNodes[0].Value;
                    RorelsekostnaderRES0Obj = null;
                }
                XmlNode RorelsekostnaderRESm1Obj = root.SelectSingleNode("se-gen-base:Rorelsekostnader[@contextRef='PERIOD-1']", genbase);
                if ((RorelsekostnaderRESm1Obj != null))
                {
                    RorelsekostnaderRESm1.Text = RorelsekostnaderRESm1Obj.ChildNodes[0].Value;
                    RorelsekostnaderRESm1Obj = null;
                }

                XmlNode RorelseresultatRES0Obj = root.SelectSingleNode("se-gen-base:Rorelseresultat[@contextRef='PERIOD0']", genbase);
                if ((RorelseresultatRES0Obj != null))
                {
                    RorelseresultatRES0.Text = RorelseresultatRES0Obj.ChildNodes[0].Value;
                    RorelseresultatRES0Obj = null;
                }
                XmlNode RorelseresultatRESm1Obj = root.SelectSingleNode("se-gen-base:Rorelseresultat[@contextRef='PERIOD-1']", genbase);
                if ((RorelseresultatRESm1Obj != null))
                {
                    RorelseresultatRESm1.Text = RorelseresultatRESm1Obj.ChildNodes[0].Value;
                    RorelseresultatRESm1Obj = null;
                }

                // Finansiella poster
                XmlNode ResultatFranAndelarIKoncernforetagRES0Obj = root.SelectSingleNode("se-gen-base:ResultatAndelarKoncernforetag[@contextRef='PERIOD0']", genbase);
                if ((ResultatFranAndelarIKoncernforetagRES0Obj != null))
                {
                    ResultatFranAndelarIKoncernforetagRES0.Text = ResultatFranAndelarIKoncernforetagRES0Obj.ChildNodes[0].Value;
                    ResultatFranAndelarIKoncernforetagRES0Obj = null;
                }
                XmlNode ResultatFranAndelarIKoncernforetagRESm1Obj = root.SelectSingleNode("se-gen-base:ResultatAndelarKoncernforetag[@contextRef='PERIOD-1']", genbase);
                if ((ResultatFranAndelarIKoncernforetagRESm1Obj != null))
                {
                    ResultatFranAndelarIKoncernforetagRESm1.Text = ResultatFranAndelarIKoncernforetagRESm1Obj.ChildNodes[0].Value;
                    ResultatFranAndelarIKoncernforetagRESm1Obj = null;
                }
                XmlNode ResultatFranAndelarIIntresseforetagRES0Obj = root.SelectSingleNode("se-gen-base:ResultatAndelarIntresseforetag[@contextRef='PERIOD0']", genbase);
                if ((ResultatFranAndelarIIntresseforetagRES0Obj != null))
                {
                    ResultatFranAndelarIIntresseforetagRES0.Text = ResultatFranAndelarIIntresseforetagRES0Obj.ChildNodes[0].Value;
                    ResultatFranAndelarIIntresseforetagRES0Obj = null;
                }
                XmlNode ResultatFranAndelarIIntresseforetagRESm1Obj = root.SelectSingleNode("se-gen-base:ResultatAndelarIntresseforetag[@contextRef='PERIOD-1']", genbase);
                if ((ResultatFranAndelarIIntresseforetagRESm1Obj != null))
                {
                    ResultatFranAndelarIIntresseforetagRESm1.Text = ResultatFranAndelarIIntresseforetagRESm1Obj.ChildNodes[0].Value;
                    ResultatFranAndelarIIntresseforetagRESm1Obj = null;
                }
                XmlNode ResultatFranOvrigaFinansiellaAnlaggningstillgangarRES0Obj = root.SelectSingleNode("se-gen-base:ResultatOvrigaFinansiellaAnlaggningstillgangar[@contextRef='PERIOD0']", genbase);
                if ((ResultatFranOvrigaFinansiellaAnlaggningstillgangarRES0Obj != null))
                {
                    ResultatFranOvrigaFinansiellaAnlaggningstillgangarRES0.Text = ResultatFranOvrigaFinansiellaAnlaggningstillgangarRES0Obj.ChildNodes[0].Value;
                    ResultatFranOvrigaFinansiellaAnlaggningstillgangarRES0Obj = null;
                }
                XmlNode ResultatFranOvrigaFinansiellaAnlaggningstillgangarRESm1Obj = root.SelectSingleNode("se-gen-base:ResultatOvrigaFinansiellaAnlaggningstillgangar[@contextRef='PERIOD-1']", genbase);
                if ((ResultatFranOvrigaFinansiellaAnlaggningstillgangarRESm1Obj != null))
                {
                    ResultatFranOvrigaFinansiellaAnlaggningstillgangarRESm1.Text = ResultatFranOvrigaFinansiellaAnlaggningstillgangarRESm1Obj.ChildNodes[0].Value;
                    ResultatFranOvrigaFinansiellaAnlaggningstillgangarRESm1Obj = null;
                }
                XmlNode OvrigaRanteintakterOchLiknandeResultatposterRES0Obj = root.SelectSingleNode("se-gen-base:OvrigaRanteintakterOchLiknandeResultatposter[@contextRef='PERIOD0']", genbase);
                if ((OvrigaRanteintakterOchLiknandeResultatposterRES0Obj != null))
                {
                    OvrigaRanteintakterOchLiknandeResultatposterRES0.Text = OvrigaRanteintakterOchLiknandeResultatposterRES0Obj.ChildNodes[0].Value;
                    OvrigaRanteintakterOchLiknandeResultatposterRES0Obj = null;
                }
                XmlNode OvrigaRanteintakterOchLiknandeResultatposterRESm1Obj = root.SelectSingleNode("se-gen-base:OvrigaRanteintakterOchLiknandeResultatposter[@contextRef='PERIOD-1']", genbase);
                if ((OvrigaRanteintakterOchLiknandeResultatposterRESm1Obj != null))
                {
                    OvrigaRanteintakterOchLiknandeResultatposterRESm1.Text = OvrigaRanteintakterOchLiknandeResultatposterRESm1Obj.ChildNodes[0].Value;
                    OvrigaRanteintakterOchLiknandeResultatposterRESm1Obj = null;
                }
                XmlNode NedskrivningarAvFinansiellaAnlaggningstillgangarOchKortfristigaPlaceringarRES0Obj = root.SelectSingleNode("se-gen-base:NedskrivningarFinansiellaAnlaggningstillgangarOchKortfristigaPlaceringar[@contextRef='PERIOD0']", genbase);
                if ((NedskrivningarAvFinansiellaAnlaggningstillgangarOchKortfristigaPlaceringarRES0Obj != null))
                {
                    NedskrivningarAvFinansiellaAnlaggningstillgangarOchKortfristigaPlaceringarRES0.Text = NedskrivningarAvFinansiellaAnlaggningstillgangarOchKortfristigaPlaceringarRES0Obj.ChildNodes[0].Value;
                    NedskrivningarAvFinansiellaAnlaggningstillgangarOchKortfristigaPlaceringarRES0Obj = null;
                }
                XmlNode NedskrivningarAvFinansiellaAnlaggningstillgangarOchKortfristigaPlaceringarRESm1Obj = root.SelectSingleNode("se-gen-base:NedskrivningarFinansiellaAnlaggningstillgangarOchKortfristigaPlaceringar[@contextRef='PERIOD-1']", genbase);
                if ((NedskrivningarAvFinansiellaAnlaggningstillgangarOchKortfristigaPlaceringarRESm1Obj != null))
                {
                    NedskrivningarAvFinansiellaAnlaggningstillgangarOchKortfristigaPlaceringarRESm1.Text = NedskrivningarAvFinansiellaAnlaggningstillgangarOchKortfristigaPlaceringarRESm1Obj.ChildNodes[0].Value;
                    NedskrivningarAvFinansiellaAnlaggningstillgangarOchKortfristigaPlaceringarRESm1Obj = null;
                }
                XmlNode RantekostnaderOchLiknandeResultatposterRES0Obj = root.SelectSingleNode("se-gen-base:RantekostnaderOchLiknandeResultatposter[@contextRef='PERIOD0']", genbase);
                if ((RantekostnaderOchLiknandeResultatposterRES0Obj != null))
                {
                    RantekostnaderOchLiknandeResultatposterRES0.Text = RantekostnaderOchLiknandeResultatposterRES0Obj.ChildNodes[0].Value;
                    RantekostnaderOchLiknandeResultatposterRES0Obj = null;
                }
                XmlNode RantekostnaderOchLiknandeResultatposterRESm1Obj = root.SelectSingleNode("se-gen-base:RantekostnaderOchLiknandeResultatposter[@contextRef='PERIOD-1']", genbase);
                if ((RantekostnaderOchLiknandeResultatposterRESm1Obj != null))
                {
                    RantekostnaderOchLiknandeResultatposterRESm1.Text = RantekostnaderOchLiknandeResultatposterRESm1Obj.ChildNodes[0].Value;
                    RantekostnaderOchLiknandeResultatposterRESm1Obj = null;
                }
                XmlNode SummaFinPosterRES0Obj = root.SelectSingleNode("se-gen-base:FinansiellaPosterSumma[@contextRef='PERIOD0']", genbase);
                if ((SummaFinPosterRES0Obj != null))
                {
                    SummaFinPosterRES0.Text = SummaFinPosterRES0Obj.ChildNodes[0].Value;
                    SummaFinPosterRES0Obj = null;
                }
                XmlNode SummaFinPosterRESm1Obj = root.SelectSingleNode("se-gen-base:FinansiellaPosterSumma[@contextRef='PERIOD-1']", genbase);
                if ((SummaFinPosterRESm1Obj != null))
                {
                    SummaFinPosterRESm1.Text = SummaFinPosterRESm1Obj.ChildNodes[0].Value;
                    SummaFinPosterRESm1Obj = null;
                }

                XmlNode ResultatEfterFinansiellaPosterRES0Obj = root.SelectSingleNode("se-gen-base:ResultatEfterFinansiellaPoster[@contextRef='PERIOD0']", genbase);
                if ((ResultatEfterFinansiellaPosterRES0Obj != null))
                {
                    ResultatEfterFinansiellaPosterRES0.Text = ResultatEfterFinansiellaPosterRES0Obj.ChildNodes[0].Value;
                    ResultatEfterFinansiellaPosterRES0Obj = null;
                }
                XmlNode ResultatEfterFinansiellaPosterRESm1Obj = root.SelectSingleNode("se-gen-base:ResultatEfterFinansiellaPoster[@contextRef='PERIOD-1']", genbase);
                if ((ResultatEfterFinansiellaPosterRESm1Obj != null))
                {
                    ResultatEfterFinansiellaPosterRESm1.Text = ResultatEfterFinansiellaPosterRESm1Obj.ChildNodes[0].Value;
                    ResultatEfterFinansiellaPosterRESm1Obj = null;
                }

                // Extraordinara poster
                XmlNode ExtraordinaraIntakterRES0Obj = root.SelectSingleNode("se-gen-base:ExtraordinaraIntakter[@contextRef='PERIOD0']", genbase);
                if ((ExtraordinaraIntakterRES0Obj != null))
                {
                    ExtraordinaraIntakterRES0.Text = ExtraordinaraIntakterRES0Obj.ChildNodes[0].Value;
                    ExtraordinaraIntakterRES0Obj = null;
                }
                XmlNode ExtraordinaraIntakterRESm1Obj = root.SelectSingleNode("se-gen-base:ExtraordinaraIntakter[@contextRef='PERIOD-1']", genbase);
                if ((ExtraordinaraIntakterRESm1Obj != null))
                {
                    ExtraordinaraIntakterRESm1.Text = ExtraordinaraIntakterRESm1Obj.ChildNodes[0].Value;
                    ExtraordinaraIntakterRESm1Obj = null;
                }
                XmlNode ExtraordinaraKostnaderRES0Obj = root.SelectSingleNode("se-gen-base:ExtraordinaraKostnader[@contextRef='PERIOD0']", genbase);
                if ((ExtraordinaraKostnaderRES0Obj != null))
                {
                    ExtraordinaraKostnaderRES0.Text = ExtraordinaraKostnaderRES0Obj.ChildNodes[0].Value;
                    ExtraordinaraKostnaderRES0Obj = null;
                }
                XmlNode ExtraordinaraKostnaderRESm1Obj = root.SelectSingleNode("se-gen-base:ExtraordinaraKostnader[@contextRef='PERIOD-1']", genbase);
                if ((ExtraordinaraKostnaderRESm1Obj != null))
                {
                    ExtraordinaraKostnaderRESm1.Text = ExtraordinaraKostnaderRESm1Obj.ChildNodes[0].Value;
                    ExtraordinaraKostnaderRESm1Obj = null;
                }

                XmlNode ResultatForeBokslutsdispositionerOchSkattRES0Obj = root.SelectSingleNode("se-gen-base:ResultatForeBokslutsdispositionerOchSkatt[@contextRef='PERIOD0']", genbase);
                if ((ResultatForeBokslutsdispositionerOchSkattRES0Obj != null))
                {
                    ResultatForeBokslutsdispositionerOchSkattRES0.Text = ResultatForeBokslutsdispositionerOchSkattRES0Obj.ChildNodes[0].Value;
                    ResultatForeBokslutsdispositionerOchSkattRES0Obj = null;
                }
                XmlNode ResultatForeBokslutsdispositionerOchSkattRESm1Obj = root.SelectSingleNode("se-gen-base:ResultatForeBokslutsdispositionerOchSkatt[@contextRef='PERIOD-1']", genbase);
                if ((ResultatForeBokslutsdispositionerOchSkattRESm1Obj != null))
                {
                    ResultatForeBokslutsdispositionerOchSkattRESm1.Text = ResultatForeBokslutsdispositionerOchSkattRESm1Obj.ChildNodes[0].Value;
                    ResultatForeBokslutsdispositionerOchSkattRESm1Obj = null;
                }

                // Bokslutsdispositioner
                XmlNode ForandringAvPeriodiseringsfondRES0Obj = root.SelectSingleNode("se-gen-base:ForandringPeriodiseringsfond[@contextRef='PERIOD0']", genbase);
                if ((ForandringAvPeriodiseringsfondRES0Obj != null))
                {
                    ForandringAvPeriodiseringsfondRES0.Text = ForandringAvPeriodiseringsfondRES0Obj.ChildNodes[0].Value;
                    ForandringAvPeriodiseringsfondRES0Obj = null;
                }
                XmlNode ForandringAvPeriodiseringsfondRESm1Obj = root.SelectSingleNode("se-gen-base:ForandringPeriodiseringsfond[@contextRef='PERIOD-1']", genbase);
                if ((ForandringAvPeriodiseringsfondRESm1Obj != null))
                {
                    ForandringAvPeriodiseringsfondRESm1.Text = ForandringAvPeriodiseringsfondRESm1Obj.ChildNodes[0].Value;
                    ForandringAvPeriodiseringsfondRESm1Obj = null;
                }
                XmlNode ForandringAvOveravskrivningarRES0Obj = root.SelectSingleNode("se-gen-base:ForandringOveravskrivningar[@contextRef='PERIOD0']", genbase);
                if ((ForandringAvOveravskrivningarRES0Obj != null))
                {
                    ForandringAvOveravskrivningarRES0.Text = ForandringAvOveravskrivningarRES0Obj.ChildNodes[0].Value;
                    ForandringAvOveravskrivningarRES0Obj = null;
                }
                XmlNode ForandringAvOveravskrivningarRESm1Obj = root.SelectSingleNode("se-gen-base:ForandringOveravskrivningar[@contextRef='PERIOD-1']", genbase);
                if ((ForandringAvOveravskrivningarRESm1Obj != null))
                {
                    ForandringAvOveravskrivningarRESm1.Text = ForandringAvOveravskrivningarRESm1Obj.ChildNodes[0].Value;
                    ForandringAvOveravskrivningarRESm1Obj = null;
                }
                XmlNode ErhallnaKoncernbidragRES0Obj = root.SelectSingleNode("se-gen-base:ErhallnaKoncernbidrag[@contextRef='PERIOD0']", genbase);
                if ((ErhallnaKoncernbidragRES0Obj != null))
                {
                    ErhallnaKoncernbidragRES0.Text = ErhallnaKoncernbidragRES0Obj.ChildNodes[0].Value;
                    ErhallnaKoncernbidragRES0Obj = null;
                }
                XmlNode ErhallnaKoncernbidragRESm1Obj = root.SelectSingleNode("se-gen-base:ErhallnaKoncernbidrag[@contextRef='PERIOD-1']", genbase);
                if ((ErhallnaKoncernbidragRESm1Obj != null))
                {
                    ErhallnaKoncernbidragRESm1.Text = ErhallnaKoncernbidragRESm1Obj.ChildNodes[0].Value;
                    ErhallnaKoncernbidragRESm1Obj = null;
                }
                XmlNode LamnadeKoncernbidragRES0Obj = root.SelectSingleNode("se-gen-base:LamnadeKoncernbidrag[@contextRef='PERIOD0']", genbase);
                if ((LamnadeKoncernbidragRES0Obj != null))
                {
                    LamnadeKoncernbidragRES0.Text = LamnadeKoncernbidragRES0Obj.ChildNodes[0].Value;
                    LamnadeKoncernbidragRES0Obj = null;
                }
                XmlNode LamnadeKoncernbidragRESm1Obj = root.SelectSingleNode("se-gen-base:LamnadeKoncernbidrag[@contextRef='PERIOD-1']", genbase);
                if ((LamnadeKoncernbidragRESm1Obj != null))
                {
                    LamnadeKoncernbidragRESm1.Text = LamnadeKoncernbidragRESm1Obj.ChildNodes[0].Value;
                    LamnadeKoncernbidragRESm1Obj = null;
                }
                XmlNode OvrigaBokslutsdispositionerRES0Obj = root.SelectSingleNode("se-gen-base:OvrigaBokslutsdispositioner[@contextRef='PERIOD0']", genbase);
                if ((OvrigaBokslutsdispositionerRES0Obj != null))
                {
                    OvrigaBokslutsdispositionerRES0.Text = OvrigaBokslutsdispositionerRES0Obj.ChildNodes[0].Value;
                    OvrigaBokslutsdispositionerRES0Obj = null;
                }
                XmlNode OvrigaBokslutsdispositionerRESm1Obj = root.SelectSingleNode("se-gen-base:OvrigaBokslutsdispositioner[@contextRef='PERIOD-1']", genbase);
                if ((OvrigaBokslutsdispositionerRESm1Obj != null))
                {
                    OvrigaBokslutsdispositionerRESm1.Text = OvrigaBokslutsdispositionerRESm1Obj.ChildNodes[0].Value;
                    OvrigaBokslutsdispositionerRESm1Obj = null;
                }
                XmlNode SummaBokslutsdispositionerRES0Obj = root.SelectSingleNode("se-gen-base:BokslutsdispositionerSumma[@contextRef='PERIOD0']", genbase);
                if ((SummaBokslutsdispositionerRES0Obj != null))
                {
                    SummaBokslutsdispositionerRES0.Text = SummaBokslutsdispositionerRES0Obj.ChildNodes[0].Value;
                    SummaBokslutsdispositionerRES0Obj = null;
                }
                XmlNode SummaBokslutsdispositionerRESm1Obj = root.SelectSingleNode("se-gen-base:BokslutsdispositionerSumma[@contextRef='PERIOD-1']", genbase);
                if ((SummaBokslutsdispositionerRESm1Obj != null))
                {
                    SummaBokslutsdispositionerRESm1.Text = SummaBokslutsdispositionerRESm1Obj.ChildNodes[0].Value;
                    SummaBokslutsdispositionerRESm1Obj = null;
                }
                XmlNode ResultatForeSkattRES0Obj = root.SelectSingleNode("se-gen-base:ResultatForeSkatt[@contextRef='PERIOD0']", genbase);
                if ((ResultatForeSkattRES0Obj != null))
                {
                    ResultatForeSkattRES0.Text = ResultatForeSkattRES0Obj.ChildNodes[0].Value;
                    ResultatForeSkattRES0Obj = null;
                }
                XmlNode ResultatForeSkattRESm1Obj = root.SelectSingleNode("se-gen-base:ResultatForeSkatt[@contextRef='PERIOD-1']", genbase);
                if ((ResultatForeSkattRESm1Obj != null))
                {
                    ResultatForeSkattRESm1.Text = ResultatForeSkattRESm1Obj.ChildNodes[0].Value;
                    ResultatForeSkattRESm1Obj = null;
                }

                // Skatter och arets resultat
                XmlNode SkattPaAretsResultatRES0Obj = root.SelectSingleNode("se-gen-base:SkattAretsResultat[@contextRef='PERIOD0']", genbase);
                if ((SkattPaAretsResultatRES0Obj != null))
                {
                    SkattPaAretsResultatRES0.Text = SkattPaAretsResultatRES0Obj.ChildNodes[0].Value;
                    SkattPaAretsResultatRES0Obj = null;
                }
                XmlNode SkattPaAretsResultatRESm1Obj = root.SelectSingleNode("se-gen-base:SkattAretsResultat[@contextRef='PERIOD-1']", genbase);
                if ((SkattPaAretsResultatRESm1Obj != null))
                {
                    SkattPaAretsResultatRESm1.Text = SkattPaAretsResultatRESm1Obj.ChildNodes[0].Value;
                    SkattPaAretsResultatRESm1Obj = null;
                }
                XmlNode OvrigaSkatterRES0Obj = root.SelectSingleNode("se-gen-base:OvrigaSkatter[@contextRef='PERIOD0']", genbase);
                if ((OvrigaSkatterRES0Obj != null))
                {
                    OvrigaSkatterRES0.Text = OvrigaSkatterRES0Obj.ChildNodes[0].Value;
                    OvrigaSkatterRES0Obj = null;
                }
                XmlNode OvrigaSkatterRESm1Obj = root.SelectSingleNode("se-gen-base:OvrigaSkatter[@contextRef='PERIOD-1']", genbase);
                if ((OvrigaSkatterRESm1Obj != null))
                {
                    OvrigaSkatterRESm1.Text = OvrigaSkatterRESm1Obj.ChildNodes[0].Value;
                    OvrigaSkatterRESm1Obj = null;
                }
                XmlNode AretsResultatRES0Obj = root.SelectSingleNode("se-gen-base:AretsResultat[@contextRef='PERIOD0']", genbase);
                if ((AretsResultatRES0Obj != null))
                {
                    AretsResultatRES0.Text = AretsResultatRES0Obj.ChildNodes[0].Value;
                    AretsResultatRES0Obj = null;
                }
                XmlNode AretsResultatRESm1Obj = root.SelectSingleNode("se-gen-base:AretsResultat[@contextRef='PERIOD-1']", genbase);
                if ((AretsResultatRESm1Obj != null))
                {
                    AretsResultatRESm1.Text = AretsResultatRESm1Obj.ChildNodes[0].Value;
                    AretsResultatRESm1Obj = null;
                }


                //// //////////////////// Select nodes inside Tuple //////////////////////////////
                //// Revisionsbyra 1 period 0

                //XmlNode Revisionsbyra1Obj = root.SelectSingleNode("(//se-gen-base:ErsattningRevisorerRevisionsbyra[@contextRef='PERIOD0'])[1]", genbase);
                //if ((Revisionsbyra1Obj != null))
                //{
                //    Revisionsbyra1.Text = Revisionsbyra1Obj.ChildNodes[0].Value;
                //    Revisionsbyra1Obj = null;
                //}
                //XmlNode RevisionsuppdragRevisionsbyra1RES0Obj = root.SelectSingleNode("(//se-gen-base:ErsattningRevisorerRevisionsuppdrag[@contextRef='PERIOD0'])[1]", genbase);
                //if ((RevisionsuppdragRevisionsbyra1RES0Obj != null))
                //{
                //    RevisionsuppdragRevisionsbyra1RES0.Text = RevisionsuppdragRevisionsbyra1RES0Obj.ChildNodes[0].Value;
                //    RevisionsuppdragRevisionsbyra1RES0Obj = null;
                //}
                //XmlNode OvrigaUppdragRevisionsbyra1RES0Obj = root.SelectSingleNode("(//se-gen-base:ErsattningRevisorerOvrigaUppdrag[@contextRef='PERIOD0'])[1]", genbase);
                //if ((OvrigaUppdragRevisionsbyra1RES0Obj != null))
                //{
                //    OvrigaUppdragRevisionsbyra1RES0.Text = OvrigaUppdragRevisionsbyra1RES0Obj.ChildNodes[0].Value;
                //    OvrigaUppdragRevisionsbyra1RES0Obj = null;
                //}
                //XmlNode SummaRevisionsbyra1RES0Obj = root.SelectSingleNode("(//se-gen-base:ErsattningRevisorerSummaRevisionsbyra[@contextRef='PERIOD0'])[1]", genbase);
                //if ((SummaRevisionsbyra1RES0Obj != null))
                //{
                //    SummaRevisionsbyra1RES0.Text = SummaRevisionsbyra1RES0Obj.ChildNodes[0].Value;
                //    SummaRevisionsbyra1RES0Obj = null;
                //}

                //// Revisionsbyra 1 Period -1
                //XmlNode RevisionsuppdragRevisionsbyra1RESm1Obj = root.SelectSingleNode("(//se-gen-base:ErsattningRevisorerRevisionsuppdrag[@contextRef='PERIOD-1'])[1]", genbase);
                //if ((RevisionsuppdragRevisionsbyra1RESm1Obj != null))
                //{
                //    RevisionsuppdragRevisionsbyra1RESm1.Text = RevisionsuppdragRevisionsbyra1RESm1Obj.ChildNodes[0].Value;
                //    RevisionsuppdragRevisionsbyra1RESm1Obj = null;
                //}
                //XmlNode OvrigaUppdragRevisionsbyra1RESm1Obj = root.SelectSingleNode("(//se-gen-base:ErsattningRevisorerOvrigaUppdrag[@contextRef='PERIOD-1'])[1]", genbase);
                //if ((OvrigaUppdragRevisionsbyra1RESm1Obj != null))
                //{
                //    OvrigaUppdragRevisionsbyra1RESm1.Text = OvrigaUppdragRevisionsbyra1RESm1Obj.ChildNodes[0].Value;
                //    OvrigaUppdragRevisionsbyra1RESm1Obj = null;
                //}
                //XmlNode SummaRevisionsbyra1RESm1Obj = root.SelectSingleNode("(//se-gen-base:ErsattningRevisorerSummaRevisionsbyra[@contextRef='PERIOD-1'])[1]", genbase);
                //if ((SummaRevisionsbyra1RESm1Obj != null))
                //{
                //    SummaRevisionsbyra1RESm1.Text = SummaRevisionsbyra1RESm1Obj.ChildNodes[0].Value;
                //    SummaRevisionsbyra1RESm1Obj = null;
                //}

                //// Revisionsbyra 2 period 0
                //XmlNode Revisionsbyra2Obj = root.SelectSingleNode("(//se-gen-base:ErsattningRevisorerRevisionsbyra[@contextRef='PERIOD0'])[2]", genbase);
                //if ((Revisionsbyra2Obj != null))
                //{
                //    Revisionsbyra2.Text = Revisionsbyra2Obj.ChildNodes[0].Value;
                //    Revisionsbyra2Obj = null;
                //}
                //XmlNode RevisionsuppdragRevisionsbyra2RES0Obj = root.SelectSingleNode("(//se-gen-base:ErsattningRevisorerRevisionsuppdrag[@contextRef='PERIOD0'])[2]", genbase);
                //if ((RevisionsuppdragRevisionsbyra2RES0Obj != null))
                //{
                //    RevisionsuppdragRevisionsbyra2RES0.Text = RevisionsuppdragRevisionsbyra2RES0Obj.ChildNodes[0].Value;
                //    RevisionsuppdragRevisionsbyra2RES0Obj = null;
                //}
                //XmlNode OvrigaUppdragRevisionsbyra2RES0Obj = root.SelectSingleNode("(//se-gen-base:ErsattningRevisorerOvrigaUppdrag[@contextRef='PERIOD0'])[2]", genbase);
                //if ((OvrigaUppdragRevisionsbyra2RES0Obj != null))
                //{
                //    OvrigaUppdragRevisionsbyra2RES0.Text = OvrigaUppdragRevisionsbyra2RES0Obj.ChildNodes[0].Value;
                //    OvrigaUppdragRevisionsbyra2RES0Obj = null;
                //}
                //XmlNode SummaRevisionsbyra2RES0Obj = root.SelectSingleNode("(//se-gen-base:ErsattningRevisorerSummaRevisionsbyra[@contextRef='PERIOD0'])[2]", genbase);
                //if ((SummaRevisionsbyra2RES0Obj != null))
                //{
                //    SummaRevisionsbyra2RES0.Text = SummaRevisionsbyra2RES0Obj.ChildNodes[0].Value;
                //    SummaRevisionsbyra2RES0Obj = null;
                //}

                //// Revisionsbyra 2 period -1
                //XmlNode RevisionsuppdragRevisionsbyra2RESm1Obj = root.SelectSingleNode("(//se-gen-base:ErsattningRevisorerRevisionsuppdrag[@contextRef='PERIOD-1'])[2]", genbase);
                //if ((RevisionsuppdragRevisionsbyra2RESm1Obj != null))
                //{
                //    RevisionsuppdragRevisionsbyra2RESm1.Text = RevisionsuppdragRevisionsbyra2RESm1Obj.ChildNodes[0].Value;
                //    RevisionsuppdragRevisionsbyra2RESm1Obj = null;
                //}
                //XmlNode OvrigaUppdragRevisionsbyra2RESm1Obj = root.SelectSingleNode("(//se-gen-base:ErsattningRevisorerOvrigaUppdrag[@contextRef='PERIOD-1'])[2]", genbase);
                //if ((OvrigaUppdragRevisionsbyra2RESm1Obj != null))
                //{
                //    OvrigaUppdragRevisionsbyra2RESm1.Text = OvrigaUppdragRevisionsbyra2RESm1Obj.ChildNodes[0].Value;
                //    OvrigaUppdragRevisionsbyra2RESm1Obj = null;
                //}
                //XmlNode SummaRevisionsbyra2RESm1Obj = root.SelectSingleNode("(//se-gen-base:ErsattningRevisorerSummaRevisionsbyra[@contextRef='PERIOD-1'])[2]", genbase);
                //if ((SummaRevisionsbyra2RESm1Obj != null))
                //{
                //    SummaRevisionsbyra2RESm1.Text = SummaRevisionsbyra2RESm1Obj.ChildNodes[0].Value;
                //    SummaRevisionsbyra2RESm1Obj = null;
                //}

                //// /////////////////////// Select childnodes with For Each //////////////////////////
                //// Ingaende belopp
                //XmlNode IngaendebeloppObj = root.SelectSingleNode("se-gen-base:ForandringEgetKapitalBFNTuple[se-gen-base:ForandringEgetKapitalBFNBeloppsslag='Ingende belopp']", genbase);
                //if ((IngaendebeloppObj != null))
                //{
                //    foreach (XmlNode n in IngaendebeloppObj.ChildNodes)
                //    {
                //        switch (n.Name)
                //        {
                //            case "se-gen-base:ForandringEgetKapitalBFNAktiekapital":
                //                IngaendebeloppAktiekapital.Text = n.InnerText;
                //                break;
                //            case "se-gen-base:ForandringEgetKapitalBFNEjRegistreratAktiekapital":
                //                IngaendebeloppEjRegistreratAktiekapital.Text = n.InnerText;
                //                break;
                //            case "se-gen-base:ForandringEgetKapitalBFNUppskrivningsfond":
                //                IngaendebeloppUppskrivningsfond.Text = n.InnerText;
                //                break;
                //            case "se-gen-base:ForandringEgetKapitalBFNReservfond":
                //                IngaendebeloppReservfond.Text = n.InnerText;
                //                break;
                //            case "se-gen-base:ForandringEgetKapitalBFNOverkursfond":
                //                IngaendebeloppOverkursfond.Text = n.InnerText;
                //                break;
                //            case "se-gen-base:ForandringEgetKapitalBFNFondForVerkligtVarde":
                //                IngaendebeloppFondVerkligtVarde.Text = n.InnerText;
                //                break;
                //            case "se-gen-base:ForandringEgetKapitalBFNFrittEgetKapital":
                //                IngaendebeloppFrittEgetKapital.Text = n.InnerText;
                //                break;
                //            case "se-gen-base:ForandringEgetKapitalBFNTotalt":
                //                IngaendebeloppTotalt.Text = n.InnerText;
                //                break;
                //        }
                //    }
                //}
            }
        }
    }

    protected void txtBeloppsformat_SelectedIndexChanged(object sender, System.EventArgs e)
    {
        if (txtBeloppsformat.SelectedValue == "NORMALFORM")
        {
            txtDecimals.Text = "INF";
        }
        else
        {
            txtDecimals.Text = "-3";
        }
    }
}
